# -*- coding: utf-8 -*-
import pytest

from mtpylon.service_schema.service_schema import service_schema
from mtpylon.schema import CombinatorData, FunctionData


service_schema_dict = {
    "constructors": [
        {
            "id": 85337187,
            "predicate": "resPQ",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "pq",
                    "type": "bytes"
                },
                {
                    "name": "server_public_key_fingerprints",
                    "type": "Vector<long>"
                }
            ],
            "type": "ResPQ"
        },
        {
            "id": -2083955988,
            "predicate": "p_q_inner_data",
            "params": [
                {
                    "name": "pq",
                    "type": "bytes"
                },
                {
                    "name": "p",
                    "type": "bytes"
                },
                {
                    "name": "q",
                    "type": "bytes"
                },
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "new_nonce",
                    "type": "int256"
                }
            ],
            "type": "P_Q_inner_data"
        },
        {
            "id": -1443537003,
            "predicate": "p_q_inner_data_dc",
            "params": [
                {
                    "name": "pq",
                    "type": "bytes"
                },
                {
                    "name": "p",
                    "type": "bytes"
                },
                {
                    "name": "q",
                    "type": "bytes"
                },
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "new_nonce",
                    "type": "int256"
                },
                {
                    "name": "dc",
                    "type": "int"
                }
            ],
            "type": "P_Q_inner_data"
        },
        {
            "id": 1013613780,
            "predicate": "p_q_inner_data_temp",
            "params": [
                {
                    "name": "pq",
                    "type": "bytes"
                },
                {
                    "name": "p",
                    "type": "bytes"
                },
                {
                    "name": "q",
                    "type": "bytes"
                },
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "new_nonce",
                    "type": "int256"
                },
                {
                    "name": "expires_in",
                    "type": "int"
                }
            ],
            "type": "P_Q_inner_data"
        },
        {
            "id": 1459478408,
            "predicate": "p_q_inner_data_temp_dc",
            "params": [
                {
                    "name": "pq",
                    "type": "bytes"
                },
                {
                    "name": "p",
                    "type": "bytes"
                },
                {
                    "name": "q",
                    "type": "bytes"
                },
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "new_nonce",
                    "type": "int256"
                },
                {
                    "name": "dc",
                    "type": "int"
                },
                {
                    "name": "expires_in",
                    "type": "int"
                }
            ],
            "type": "P_Q_inner_data"
        },
        {
            "id": 2043348061,
            "predicate": "server_DH_params_fail",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "new_nonce_hash",
                    "type": "int128"
                }
            ],
            "type": "Server_DH_Params"
        },
        {
            "id": -790100132,
            "predicate": "server_DH_params_ok",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "encrypted_answer",
                    "type": "bytes"
                }
            ],
            "type": "Server_DH_Params"
        },
        {
            "id": -1249309254,
            "predicate": "server_DH_inner_data",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "g",
                    "type": "int"
                },
                {
                    "name": "dh_prime",
                    "type": "bytes"
                },
                {
                    "name": "g_a",
                    "type": "bytes"
                },
                {
                    "name": "server_time",
                    "type": "int"
                }
            ],
            "type": "Server_DH_inner_data"
        },
        {
            "id": 1715713620,
            "predicate": "client_DH_inner_data",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "retry_id",
                    "type": "long"
                },
                {
                    "name": "g_b",
                    "type": "bytes"
                }
            ],
            "type": "Client_DH_Inner_Data"
        },
        {
            "id": 1003222836,
            "predicate": "dh_gen_ok",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "new_nonce_hash1",
                    "type": "int128"
                }
            ],
            "type": "Set_client_DH_params_answer"
        },
        {
            "id": 1188831161,
            "predicate": "dh_gen_retry",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "new_nonce_hash2",
                    "type": "int128"
                }
            ],
            "type": "Set_client_DH_params_answer"
        },
        {
            "id": -1499615742,
            "predicate": "dh_gen_fail",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "new_nonce_hash3",
                    "type": "int128"
                }
            ],
            "type": "Set_client_DH_params_answer"
        },
        {
            "id": -212046591,
            "predicate": "rpc_result",
            "params": [
                {
                    "name": "req_msg_id",
                    "type": "long"
                },
                {
                    "name": "result",
                    "type": "Object"
                }
            ],
            "type": "RpcResult"
        },
        {
            "id": 558156313,
            "predicate": "rpc_error",
            "params": [
                {
                    "name": "error_code",
                    "type": "int"
                },
                {
                    "name": "error_message",
                    "type": "string"
                }
            ],
            "type": "RpcError"
        },
        {
            "id": 1579864942,
            "predicate": "rpc_answer_unknown",
            "params": [],
            "type": "RpcDropAnswer"
        },
        {
            "id": -847714938,
            "predicate": "rpc_answer_dropped_running",
            "params": [],
            "type": "RpcDropAnswer"
        },
        {
            "id": -1539647305,
            "predicate": "rpc_answer_dropped",
            "params": [
                {
                    "name": "msg_id",
                    "type": "long"
                },
                {
                    "name": "seq_no",
                    "type": "int"
                },
                {
                    "name": "bytes",
                    "type": "int"
                }
            ],
            "type": "RpcDropAnswer"
        },
        {
            "id": 155834844,
            "predicate": "future_salt",
            "params": [
                {
                    "name": "valid_since",
                    "type": "int"
                },
                {
                    "name": "valid_until",
                    "type": "int"
                },
                {
                    "name": "salt",
                    "type": "long"
                }
            ],
            "type": "FutureSalt"
        },
        # {
        #   "id": -1370486635,
        #   "predicate": "future_salts",
        #   "params": [
        #     {
        #       "name": "req_msg_id",
        #       "type": "long"
        #     },
        #     {
        #       "name": "now",
        #       "type": "int"
        #     },
        #     {
        #       "name": "salts",
        #       "type": "vector<future_salt>"
        #     }
        #   ],
        #   "type": "FutureSalts"
        # },
        {
            "id": 880243653,
            "predicate": "pong",
            "params": [
                {
                    "name": "msg_id",
                    "type": "long"
                },
                {
                    "name": "ping_id",
                    "type": "long"
                }
            ],
            "type": "Pong"
        },
        {
            "id": -1631450872,
            "predicate": "new_session_created",
            "params": [
                {
                    "name": "first_msg_id",
                    "type": "long"
                },
                {
                    "name": "unique_id",
                    "type": "long"
                },
                {
                    "name": "server_salt",
                    "type": "long"
                }
            ],
            "type": "NewSession"
        },
        {
            "id": 1945237724,
            "predicate": "msg_container",
            "params": [
                {
                    "name": "messages",
                    "type": "vector<%Message>"
                }
            ],
            "type": "MessageContainer"
        },
        {
            "id": 1538843921,
            "predicate": "message",
            "params": [
                {
                    "name": "msg_id",
                    "type": "long"
                },
                {
                    "name": "seqno",
                    "type": "int"
                },
                {
                    "name": "bytes",
                    "type": "int"
                },
                {
                    "name": "body",
                    "type": "Object"
                }
            ],
            "type": "Message"
        },
        {
            "id": -530561358,
            "predicate": "msg_copy",
            "params": [
                {
                    "name": "orig_message",
                    "type": "Message"
                }
            ],
            "type": "MessageCopy"
        },
        # {
        #   "id": 812830625,
        #   "predicate": "gzip_packed",
        #   "params": [
        #     {
        #       "name": "packed_data",
        #       "type": "bytes"
        #     }
        #   ],
        #   "type": "Object"
        # },
        {
            "id": 1658238041,
            "predicate": "msgs_ack",
            "params": [
                {
                    "name": "msg_ids",
                    "type": "Vector<long>"
                }
            ],
            "type": "MsgsAck"
        },
        {
            "id": -1477445615,
            "predicate": "bad_msg_notification",
            "params": [
                {
                    "name": "bad_msg_id",
                    "type": "long"
                },
                {
                    "name": "bad_msg_seqno",
                    "type": "int"
                },
                {
                    "name": "error_code",
                    "type": "int"
                }
            ],
            "type": "BadMsgNotification"
        },
        {
            "id": -307542917,
            "predicate": "bad_server_salt",
            "params": [
                {
                    "name": "bad_msg_id",
                    "type": "long"
                },
                {
                    "name": "bad_msg_seqno",
                    "type": "int"
                },
                {
                    "name": "error_code",
                    "type": "int"
                },
                {
                    "name": "new_server_salt",
                    "type": "long"
                }
            ],
            "type": "BadMsgNotification"
        },
        {
            "id": 2105940488,
            "predicate": "msg_resend_req",
            "params": [
                {
                    "name": "msg_ids",
                    "type": "Vector<long>"
                }
            ],
            "type": "MsgResendReq"
        },
        {
            "id": -2045723925,
            "predicate": "msg_resend_ans_req",
            "params": [
                {
                    "name": "msg_ids",
                    "type": "Vector<long>"
                }
            ],
            "type": "MsgResendReq"
        },
        {
            "id": -630588590,
            "predicate": "msgs_state_req",
            "params": [
                {
                    "name": "msg_ids",
                    "type": "Vector<long>"
                }
            ],
            "type": "MsgsStateReq"
        },
        {
            "id": 81704317,
            "predicate": "msgs_state_info",
            "params": [
                {
                    "name": "req_msg_id",
                    "type": "long"
                },
                {
                    "name": "info",
                    "type": "bytes"
                }
            ],
            "type": "MsgsStateInfo"
        },
        {
            "id": -1933520591,
            "predicate": "msgs_all_info",
            "params": [
                {
                    "name": "msg_ids",
                    "type": "Vector<long>"
                },
                {
                    "name": "info",
                    "type": "bytes"
                }
            ],
            "type": "MsgsAllInfo"
        },
        {
            "id": 661470918,
            "predicate": "msg_detailed_info",
            "params": [
                {
                    "name": "msg_id",
                    "type": "long"
                },
                {
                    "name": "answer_msg_id",
                    "type": "long"
                },
                {
                    "name": "bytes",
                    "type": "int"
                },
                {
                    "name": "status",
                    "type": "int"
                }
            ],
            "type": "MsgDetailedInfo"
        },
        {
            "id": -2137147681,
            "predicate": "msg_new_detailed_info",
            "params": [
                {
                    "name": "answer_msg_id",
                    "type": "long"
                },
                {
                    "name": "bytes",
                    "type": "int"
                },
                {
                    "name": "status",
                    "type": "int"
                }
            ],
            "type": "MsgDetailedInfo"
        },
        {
            "id": 1973679973,
            "predicate": "bind_auth_key_inner",
            "params": [
                {
                    "name": "nonce",
                    "type": "long"
                },
                {
                    "name": "temp_auth_key_id",
                    "type": "long"
                },
                {
                    "name": "perm_auth_key_id",
                    "type": "long"
                },
                {
                    "name": "temp_session_id",
                    "type": "long"
                },
                {
                    "name": "expires_at",
                    "type": "int"
                }
            ],
            "type": "BindAuthKeyInner"
        },
        {
            "id": -161422892,
            "predicate": "destroy_auth_key_ok",
            "params": [],
            "type": "DestroyAuthKeyRes"
        },
        {
            "id": 178201177,
            "predicate": "destroy_auth_key_none",
            "params": [],
            "type": "DestroyAuthKeyRes"
        },
        {
            "id": -368010477,
            "predicate": "destroy_auth_key_fail",
            "params": [],
            "type": "DestroyAuthKeyRes"
        },
        {
            "id": -501201412,
            "predicate": "destroy_session_ok",
            "params": [
                {
                    "name": "session_id",
                    "type": "long"
                }
            ],
            "type": "DestroySessionRes"
        },
        {
            "id": 1658015945,
            "predicate": "destroy_session_none",
            "params": [
                {
                    "name": "session_id",
                    "type": "long"
                }
            ],
            "type": "DestroySessionRes"
        }
    ],
    "methods": [
        {
            "id": 1615239032,
            "method": "req_pq",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                }
            ],
            "type": "ResPQ"
        },
        {
            "id": -1099002127,
            "method": "req_pq_multi",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                }
            ],
            "type": "ResPQ"
        },
        {
            "id": -686627650,
            "method": "req_DH_params",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "p",
                    "type": "bytes"
                },
                {
                    "name": "q",
                    "type": "bytes"
                },
                {
                    "name": "public_key_fingerprint",
                    "type": "long"
                },
                {
                    "name": "encrypted_data",
                    "type": "bytes"
                }
            ],
            "type": "Server_DH_Params"
        },
        {
            "id": -184262881,
            "method": "set_client_DH_params",
            "params": [
                {
                    "name": "nonce",
                    "type": "int128"
                },
                {
                    "name": "server_nonce",
                    "type": "int128"
                },
                {
                    "name": "encrypted_data",
                    "type": "bytes"
                }
            ],
            "type": "Set_client_DH_params_answer"
        },
        {
            "id": 1491380032,
            "method": "rpc_drop_answer",
            "params": [
                {
                    "name": "req_msg_id",
                    "type": "long"
                }
            ],
            "type": "RpcDropAnswer"
        },
        {
            "id": -1188971260,
            "method": "get_future_salts",
            "params": [
                {
                    "name": "num",
                    "type": "int"
                }
            ],
            "type": "FutureSalts"
        },
        {
            "id": 2059302892,
            "method": "ping",
            "params": [
                {
                    "name": "ping_id",
                    "type": "long"
                }
            ],
            "type": "Pong"
        },
        {
            "id": -213746804,
            "method": "ping_delay_disconnect",
            "params": [
                {
                    "name": "ping_id",
                    "type": "long"
                },
                {
                    "name": "disconnect_delay",
                    "type": "int"
                }
            ],
            "type": "Pong"
        },
        {
            "id": -784117408,
            "method": "destroy_auth_key",
            "params": [],
            "type": "DestroyAuthKeyRes"
        },
        {
            "id": -414113498,
            "method": "destroy_session",
            "params": [
                {
                    "name": "session_id",
                    "type": "long"
                }
            ],
            "type": "DestroySessionRes"
        }
    ]
}


@pytest.mark.parametrize(
    'service_constructor',
    service_schema_dict['constructors'],
    ids=lambda x: f"[{x['type']}] {x['predicate']}"
)
def test_constructors(service_constructor):
    constructor_id = service_constructor['id']
    assert constructor_id in service_schema

    data = service_schema[constructor_id]

    assert isinstance(data, CombinatorData)
    assert data.predicate == service_constructor['predicate']
    assert data.type == service_constructor['type']

    param_names = set([param.name for param in data.params])
    for param in service_constructor['params']:
        assert param['name'] in param_names


@pytest.mark.parametrize(
    'method',
    service_schema_dict['methods'],
    ids=lambda x: x['method']
)
def test_methods(method):
    method_id = method['id']

    assert method_id in service_schema

    data = service_schema[method_id]

    assert isinstance(data, FunctionData)
    assert method['method'] == data.method
    assert method['type'] == data.type

    param_names = set([param.name for param in data.params])
    for param in method['params']:
        param['name'] in param_names
